import 'package:flutter/material.dart';
import 'package:flutter_helper/flutter_helper.dart';
import 'package:flutter_helper/src/Views/IconBackgroundView.dart';
import 'package:image_picker/image_picker.dart';

class ImagePickerView extends StatelessWidget {
  final List<String> images;
  final Function addImage;
  final Function(String) removeImage;
  final bool isLoading;
  final int i;

  ImagePickerView({
    this.images,
    this.addImage,
    this.removeImage,
    this.isLoading,
    this.i
  });

  Future<ImageSource> _showDialog(BuildContext context) async {
    final ImageSource imageSource = await showDialog(context: context, builder: (context) {
      return AlertDialog(
        title: Text("Where do you want to get your pictures from?"),
        actions: [
          FlatButton(onPressed: () {
            Navigator.pop(context, ImageSource.gallery);
          }, child: Text("Gallery")),
          FlatButton(onPressed: () {
            Navigator.pop(context, ImageSource.camera);
          }, child: Text("Camera"))
        ],
      );
    });

    return imageSource;
  }


  Widget buildImageHero(String image, BuildContext context) {
    return Stack(
      clipBehavior: Clip.none,
      children: [
        Hero(
          tag: image,
          child: GestureDetector(
            onTap: () {
              Navigator.push(context, MaterialPageRoute(
                builder: (context) {
                  return GestureDetector(onTap: () {
                    Navigator.pop(context);
                  }, child: Image.network(image));
                }
              ));
            },
            child: SizedBox(
              width: 100,
              height: 100,
              child: ClipOval(
                child: ImageView(image: image),
              ),
            ),
          ),
        ),
        Positioned(
          right: -20.0,
          bottom: -20.0,
          child: IconButton(
            iconSize: 40.0,
            icon: Icon(Icons.cancel),
            onPressed: () {
              removeImage(image);
            },
          ),
        ),
      ],
    );
  }

  Widget _buildPicture(int index, BuildContext context) {
    Widget icon;

    Key key;

    if (images.length >= index) {
      icon = isLoading ? Center(child: SizedBox(width: 50.0, height: 50.0, child: CircularProgressIndicator())) : Icon(Icons.add_a_photo);

      key = Key("camera_plus");
    } else {
      icon = Icon(Icons.photo_camera);

      key = Key("camera");
    }

    Widget widget;

    if (images.length - 1 >= index) {
      widget = Column(
        children: [
          buildImageHero(images[index], context),
          TextFieldView(controller: TextEditingController()..text = images[index]),
        ],
      );
    } else {
      widget = Center(
        child: IconBackgroundView(
          key: key,
          icon: icon,
          onPressed: key == Key("camera_plus") ? () async {
            final ImageSource imageSource = await _showDialog(context);

            if (imageSource != null) {
              addImage(imageSource);
            }
          } : null,
          radius: 100.0,
        ),
      );
    }

    return Padding(
      padding: const EdgeInsets.all(16.0),
      child: widget,
    );
  }

  @override
  Widget build(BuildContext context) {
    return _buildPicture(i, context);
  }
}
